/// <reference types="react" />
import type { CellEditingStoppedEvent, CellStyleFunc, CellValueChangedEvent, ColDef, ColGroupDef, ColumnApi, ExcelExportParams, ExcelStyle, FilterChangedEvent, GridApi, GridOptions, IAggFuncParams, IRowNode, RangeSelectionChangedEvent, RowClassParams, RowClickedEvent, RowDoubleClickedEvent, RowEditingStoppedEvent, RowGroupingDisplayType, RowValueChangedEvent } from 'ag-grid-community';
import { AgGridReact } from 'ag-grid-react';
import { InputNumberProps, SelectProps, SwitchProps } from 'antd';
type MyColDef = Omit<ColDef, 'cellEditorParams' | 'filter' | 'cellStyle' | 'pinned' | 'cellEditor' | 'type' | 'comparator' | 'cellRenderer'> & {
    /**
     * 过滤类型 agDateColumnFilter=日期型 agTextColumnFilter="文本型" agNumberColumnFilter="数值型"
     */
    filter?: boolean | 'agDateColumnFilter' | 'agTextColumnFilter' | 'agNumberColumnFilter';
    cellEditor?: 'extTreeSelectEditor' | 'extDateEditor' | 'extSelectEditor' | 'extSwitchEditor' | 'agTextCellEditor' | 'agLargeTextCellEditor' | 'extNumericEditor' | 'agRichSelectCellEditor';
    cellEditorParams?: {
        [k: string]: any;
        antdSelectProps?: SelectProps;
        antdSwitchProps?: SwitchProps;
        antdInputNumberProps?: InputNumberProps;
    };
    cellStyle?: React.CSSProperties | CellStyleFunc;
    pinned?: 'left' | 'right';
    /**
     * 列属性模板
     */
    type?: 'number' | 'date';
    /**
     * 列映射枚举
     * 优先级低于  valueGetter
     */
    valueGetterEnum?: Record<any, string | number>;
    /**
     * 列值自动映射
     * @param dataName localStorage中字段名称
     * @param mapField 数据源中ID对照字段默认"id",
     * @param textField 从数据源中取的显示值对照字段默认"name",
     */
    valueGetterAutoMapper?: {
        dataName: string;
        mapField?: string;
        textField?: string;
    };
    comparator?: (valueA: any, valueB: any, nodeA: IRowNode<any>, nodeB: IRowNode<any>, isDescending: boolean) => number | '首字母' | '数字';
    cellRenderer: any | 'progress';
    rulesFieldkey: string;
    /**
     * 按单元格值和判定条件渲染单元格
     */
    predicateCellRender?: {
        rules: [
            {
                filed?: string;
                value: any;
                opt: '大于' | '大于等于' | '小于' | '小于等于' | '等于' | '不等于';
                cellStyle?: React.CSSProperties;
                compareType?: 'number' | 'string';
            }
        ];
    };
    desensitiveType: '身份证' | '手机号' | '地址';
};
type MyColGroupDef = Omit<ColGroupDef, 'children'> & {
    children?: (MyColDef | MyColGroupDef)[];
};
export declare function customAvgAggFunction(params: IAggFuncParams): number | "-";
export declare function customSumAggFunction(params: IAggFuncParams): number | "-";
export declare function customMinAggFunction(params: IAggFuncParams): number | "-";
export declare function customMaxAggFunction(params: IAggFuncParams): number | "-";
export declare function customStaticGroupAggFunction(params: IAggFuncParams, aggData: any): any;
export type AgGridApi = GridApi;
/**
 * 列类型定义
 * 带 * 号的为非原生属性
 */
export type AgGridColDef = MyColDef | MyColGroupDef;
export type IGridExportOptions = ExcelExportParams & {
    headContent?: string;
    footContent?: string;
    headContentCellMergeAcross?: number;
};
export declare const columnTypes: {
    nonEditableColumn: {
        editable: boolean;
    };
    number: {
        filter: string;
        filterParams: {
            filterOptions: (string | {
                displayKey: string;
                displayName: string;
                predicate: ([filterValue]: [any], cellValue: any) => boolean;
                numberOfInputs?: undefined;
            } | {
                displayKey: string;
                displayName: string;
                predicate: ([fv1, fv2]: [any, any], cellValue: any) => boolean;
                numberOfInputs: number;
            })[];
        };
        comparator: (a: any, b: any) => number;
        suppressMenu: boolean;
    };
    date: {
        filter: string;
        filterParams: {
            filterOptions: (string | {
                displayKey: string;
                displayName: string;
                predicate: ([filterValue]: [any], cellValue: any) => boolean;
            })[];
        };
        comparator: (a: any, b: any) => number;
        suppressMenu: boolean;
    };
};
export declare class IGridRef extends AgGridReact {
    /**
     * 导出数据到excel
     */
    ExportToExcel: (options?: IGridExportOptions) => void;
    /**
     * 跳转到指定索引行
     */
    TurnToRowIndex: (number: number) => void;
    /**
     * 指定rowid行(需定义rowid)
     */
    TurnToRowByRowID: (value: string) => void;
    /**
     * 获取筛选后的数据中选中行信息
     */
    GetSelectedRowInFilterRows: () => void;
    /**
     * 确保列可见
     */
    ensureColumnVisible: (key: string, positon: 'auto' | 'start' | 'middle' | 'end') => void;
}
export interface XDataGridExtProps {
    /**
     * @description 表格标题
     * @default null
     */
    title?: React.ReactNode | string;
    /**
     * 隐藏底部状态栏,同时会隐藏分页栏
     */
    hideStatusBar?: boolean;
    hideHead?: boolean;
    /**
     * 状态栏额外内容
     */
    StatusBarExtra?: React.ReactNode;
    /**
     * 行唯一值,强烈建议指定,减少不必要的麻烦 不指定会自动生成唯一ID
     */
    rowID?: string;
    /**
     * 隐藏斑马纹
     */
    hideZebraStripe?: boolean;
    /**
     * @description 按比例自动缩放列宽以适应容器宽度,不会出现横向滚动条
     * 请注意定义最小宽度和最大宽度,以免缩放后影响显示效果
     * @default false
     */
    autoFitWith?: boolean;
    /**
     *行号列的单元格格式
     */
    numberColCellStyle?: React.CSSProperties;
    /**
     * 根据某列值渲染行样式
     * 配置 getRowStyle 后失效
     */
    rowStyleEnum?: {
        field: string;
        value: any;
        styles: React.CSSProperties;
    }[];
    /**
     * 载入中
     */
    loading?: boolean;
    /**
     * 是否自动生成合计列
     * 提供需要生成合计列的字段 如 ['AGE','TOTAL']
     */
    autoGenSummayRow?: string[];
    /**
     * 是否使用原生滚动条
     * 滚动条样式定制后会丢失上下箭头,如果有上下箭头的需求,请开启此项
     * 注意:请检查项目中是否全局配置了滚动条样式
     * 全局滚动条样式配置后开启此项可能会导致样式错乱
     * @default false
     */
    useNativeScrollBar?: boolean; /** 调试模式 */
    debug?: boolean;
    /**
     * 主题样式
     * @default light
     */
    theme?: 'dark' | 'light' | 'fresh';
    /**
     * 通过json文件配置表格
     * 优先级最低,通过props和gridOption配置的属性将覆盖json配置
     */
    gridConfigJson?: XDataGridProps;
    /**
     * 显示选择框
     * @default false
     */
    showSelectionCol?: boolean;
    /**
     * 当前聚焦行
     * 注意 此选项需要定义表格主键rowID方可生效
     */
    focusRowId?: string;
    /**
     * 已选择行
     */
    selectedRows?: any[];
    /**
     * 关闭圆角
     */
    noBorderRadius?: boolean;
    /**
     * 空数据组件
     */
    noRowComponent?: React.ReactNode;
    /**
     * 空数据传入提示
     */
    noRowText?: string;
    /**
     * 显示行号列
     * @default false
     */
    showRowNumberCol?: boolean;
    /**
     * 状态栏不显示总记录数
     */
    noRecordCountInStatuBar?: boolean;
    /**
     * 状态栏不显示已选记录数
     */
    noSelectRowCountInStatusBar?: boolean;
    /**
     * 关闭行聚焦功能
     */
    suppressFocusRow?: boolean;
    /**
     * 禁用
     */
    disabled?: boolean;
    /**
     * 分组默认展开层级 1=第一层 -1 所有层 0=不展开
     * @default 0
     */
    groupDefaultExpanded?: number;
}
export interface XDataGridProps extends XDataGridExtProps {
    defaultColDef?: any;
    data?: any[];
    /**
     * 特定分组情况下专用静态数据
     */
    dataGroupStatic?: any[];
    /**
     * 表格初始化后回调
     * @description 详细文档  https://www.ag-grid.com/
     */
    onGridReady?: (gridApi: GridApi, columnApi?: ColumnApi) => void;
    /**
     * 显示分页条
     * @default false
     */
    pagination?: boolean;
    /**
     * 页大小
     * @default 50
     */
    paginationPageSize?: number;
    /**
     * 禁止行点击选中
     * @default false
     */
    /** 行选中 单选/多选 */
    rowSelection?: 'multiple' | 'single';
    /**
     * 禁止行点击选中,只使用 复选框选中
     */
    suppressRowClickSelection?: boolean;
    /**
     * 禁止单元格选中
     * @default false
     */
    suppressCellSelection?: boolean;
    /**
     * 是否固定
     */
    pinSelectionCol?: 'left' | 'right' | false;
    /**
     * 行选中变更事件
     */
    onSelectionChanged?: (selectedRows: any[], girdApi: GridApi) => void;
    /** 列格式定义 */
    columnDefs?: AgGridColDef[];
    /** 行样式回调 */
    getRowStyle?: (params: RowClassParams) => React.CSSProperties;
    /**
     * 额外的配置入口,大多数配置已能满足要求,此处暴露官方原生配置项,使用方式请参考官方网站
     * 优先级最高
     */
    gridOptions?: GridOptions;
    /**
     * 允许所有行编辑(需要在列中配置是否可编辑)
     * @default false
     */
    editAllRow?: boolean;
    /**
     * 允许编辑(需要在列中配置是否可编辑)
     * @default false
     */
    editable?: boolean;
    /**
     * 是否单击编辑 默认双击
     */
    singleClickEdit?: boolean;
    /**
     * 编辑模式 整行/单元格
     */
    editType?: 'fullRow' | 'cell';
    /**
     * 单元格编辑结束回调
     */
    onCellEditingStopped?: (event: CellEditingStoppedEvent) => void;
    /**
     * 行编辑结束回调
     */
    onRowEditingStopped?: (event: RowEditingStoppedEvent) => void;
    /**
     * 行数据变更
     */
    onRowValueChanged?: (event: RowValueChangedEvent<any>) => void;
    /**
     * 单元格数据变更
     */
    onCellValueChanged?: (event: CellValueChangedEvent<any>) => void;
    /**
     * 框选数据变更结束触发
     */
    afterRangeSelection?: (event: RangeSelectionChangedEvent<any>) => void;
    /**
     * 行双击事件
     * 如果使用了单击行选中,则存在事件冲突 ,建议设置 suppressRowClickSelection=true 禁止单击行选中
     */
    onRowDoubleClicked?: (event: RowDoubleClickedEvent) => void;
    /**
     * 行单击事件
     */
    onRowClicked?: (event: RowDoubleClickedEvent) => void;
    /**
     * 允许范围选择单元格
     */
    enableRangeSelection?: boolean;
    /**
     * 框选时自动选中所在行
     * 需要开启rowSelection 并处于多选multiple 模式
     */
    autoSelectRangeRow?: boolean;
    /**
     * 开启行分组功能,需要在列配置中,将允许分组的列设置 enableRowGroup: true,
     */
    allowRowGroup?: boolean;
    /**
     * 列宽变化事件
     */
    onColumnResized?: (e: any) => void;
    /**
     * 行聚焦事件
     * 注意 此选项需要定义表格主键rowID方可生效
     */
    onRowFocued?: (id?: string, e?: RowClickedEvent) => void;
    /**
     * 导出excel定义的样式表 内置样式:red/blue/yellow/green
     */
    excelStyles?: ExcelStyle[];
    /**
     * 显示数据变更回调
     * @returns 变更后的数组
     */
    onDisplayDataChange?: (filted: any[]) => void;
    onFilterChanged?: (event: FilterChangedEvent) => void;
    /**
     * 自定义的导出事件
     */
    inlineExportFunc?: (api: any) => void;
    /**
     * 自定义的CSV导出事件
     */
    inlineCsvExportFunc?: (api: any) => void;
    /**
     * 数据更新后是否重置筛选条件
     */
    keepFilerStateOnDataRefresh?: boolean;
    /**
     * 滚动防抖 低性能浏览器可以考虑开启此项
     */
    debounceVerticalScrollbar?: boolean;
    /**
     * 使用行合并时此项必须为true
     */
    suppressRowTransform?: boolean;
    /**
     * 边栏
     */
    sideBar?: boolean;
    /**
     * 分组呈现方式
     */
    groupDisplayType?: RowGroupingDisplayType | undefined;
    /**
     * 工具栏禁用全屏切换按钮
     * @default false
     */
    disableFullScreen?: boolean;
    /**
     * 工具栏禁用边栏切换按钮
     * @default false
     */
    disableSideBarToggle?: boolean;
    /**
     * 工具栏禁用导出按钮按钮
     * @default false
     */
    disableExportBtn?: boolean;
    /**
     * 分组自动包含小计行
     * @default false
     */
    groupIncludeFooter?: boolean;
    /**
     * 分组自动包含合计行
     * @default false
     */
    groupIncludeTotalFooter?: boolean;
    /**
     * 自动在状态栏中显示框选内容聚合信息 开启范围框选时适用
     */
    autoAggSelectRowInStateBar?: boolean;
    /**
     * 丢失焦点时,是否自动停止编辑状态 默认是
     * @default 是
     */
    stopEditingWhenCellsLoseFocus?: boolean;
    /**
     * 全局行高
     */
    rowHeight?: number | undefined;
    /**
     * 优化行选中渲染速度
     */
    optimizeFocus?: boolean;
}
export {};
