import moment from 'moment';
import React, { CSSProperties } from 'react';
import './datepicker.less';
import './style.less';
export interface IXDatePicker {
    onChange?: (val: moment.Moment | null) => void;
    /**
     * @description 绑定值
     * @default 当前
     */
    value?: moment.Moment | null;
    style?: CSSProperties;
    /**
     * 格式 仅支持 'YYYY-MM-DD' | 'YYYY-MM-DD HH:mm' | 'HH:mm' | 'YYYY-MM-DD HH:mm:ss'
     * @default YYYY-MM-DD HH:mm
     */
    formatter?: 'YYYY-MM-DD' | 'YYYY-MM-DD HH:mm' | 'HH:mm' | 'YYYY-MM-DD HH:mm:ss' | 'MM-DD';
    /**
     * 是否显示时间选择框
     * @default false
     */
    showTimeSelect?: boolean;
    /**
     * 是否只显示时间选择框
     * @default false
     */
    showTimeSelectOnly?: boolean;
    /**
     * 时间选择间隔(分)
     * @default 30
     */
    timeIntervals?: number;
    /**
     * 是否显示快速导航
     * @default false
     */
    fastNav?: false | '小时' | '天' | '月';
    /**
     * 是否显示周序号
     * @default false
     */
    showWeekNumbers?: boolean;
    /**
     * 默认为空
     */
    defaultNull?: boolean;
    /**
     * 弹层位置修正[左偏移,又偏移]
     */
    popOffset?: [Number, Number];
    /**
     * 小号尺寸
     */
    smallsize?: boolean;
    /**
     * 小号
     */
    smallsizePop?: boolean;
    /**
     * 只读
     */
    readOnly?: boolean;
    /**
     * 不可编辑
     */
    disabled?: boolean;
    /**
     * 允许往前选的年的数量 默认10
     * @default 10
     */
    yearSelectorPreCount?: number;
    /**
     * 允许往后选的年的数量 默认2
     * @default 2
     */
    yearSelectorSubCount?: number;
    /**
     * 可选最小时间
     */
    minDate?: moment.Moment;
    /**
     * 可选最大时间
     */
    maxDate?: moment.Moment;
    /**
     * 清除按钮
     */
    allowClear?: boolean;
}
declare const _default: React.ForwardRefExoticComponent<IXDatePicker & React.RefAttributes<unknown>>;
export default _default;
