import type { GridOptions } from 'ag-grid-enterprise';
import { TabsProps } from 'antd';
import { CSSProperties } from 'react';
import { Operator } from 'react-querybuilder';
import { AgGridColDef, XDataGridProps } from '../XDataGrid/typing';
export interface IXQueryBuilder {
    /**
     * 紧凑模式
     * @default false
     */
    compact?: boolean;
    /**
     * 类型数据列表
     * @param fieldType
     * @returns
     */
    getPredicateTypeDef: (fieldType?: string) => IPredicateItemDef;
    /**
     * 结果数据列表
     * @param classID
     * @param resultTypeID  //项目类型id
     * @param operatorName  //逻辑符name
     * @returns
     */
    getValueList: (classID?: string, resultTypeID?: string, operatorName?: string) => IValueItemDef;
    /**
     * 头部tab列表
     */
    predicateClassList: TabsProps['items'];
    /**
     * 额外区域
     */
    extraContent?: React.ReactNode;
    /**
     * 额外区域样式
     */
    extraContentStyle?: CSSProperties;
    /**
     * 初始json数据
     */
    jsonData?: object;
    /**
     * 编辑事件
     * @param info
     * @returns
     */
    onEdit?: (info: IEditType) => void;
    /**
     * json变化事件
     * @param jsonString
     * @returns
     */
    onChange?: (jsonString: string) => void;
    /**
     * 获取逻辑符
     * @param classID
     * @param resultTypeID  //resultTypeID
     * @returns
     */
    getOperatorList?: (classID?: string, resultTypeID?: string) => Operator[];
    /**
     * 获取结果类型
     * @param classID
     * @returns
     */
    getResultTypeList?: (classID?: string) => IResutType[];
    /**
     * 左侧头部区域
     */
    hearderContent?: React.ReactNode;
    /**
     * 列表是否显示序号列
     * @default false
     */
    showRowNumberCol?: boolean;
    /**
     * 布局模式
     */
    mode?: 'horizontal' | 'vertical';
    /**
     * tab修改回调
     * @param val
     * @returns
     */
    onChangeTab?: (val: string) => void;
    /**
     * 外部插入数据
     */
    buildItem?: IBuildItem;
    /**
     * 项目选择修改回调
     * @param field
     * @returns
     */
    onChangeSelect?: (field: IFieldType) => void;
    /**组件禁用 */
    diasbled?: boolean | string[];
    /**禁止新增 */
    prohibitAdd?: boolean;
}
export declare class IQueryBuilderRef {
    /**
     * 获取条件编辑结果
     */
    getRule: () => void;
}
export interface IFieldType {
    /**项目id */
    CLASS_ID: string;
    /**项目名称 */
    CLASS_NAME: string;
    /**项目类型 */
    INPUT_TYPE?: TINPUT_TYPE;
    /**类别id */
    CLASS_TYPE_ID?: string;
    /**类别名称  */
    CLASS_TYPE_NAME?: string;
    /**标签名称(展示用) */
    CLASS_TYPE_TAG?: string | any[];
    /**参考范围 */
    REFERENCE_RANGE?: string;
    /**子级 */
    childField?: IFieldType;
    /**子级选择数据 */
    data?: IFieldType[];
    /**是否是必填项 */
    IS_REQUIRE?: boolean;
    /**子级(保存数据) */
    /**结果值 */
    VALUE?: string | number;
    /**回溯天数 */
    reviewDay?: number;
    /**结果类型 */
    resultType?: string;
    resultType_type?: string;
    /**时间间隔 */
    dateRange?: number;
    /**判断结果类型选择数据 */
    judgeResult?: any;
    /**宽度 */
    width?: string;
    /**条件值是否可以为空 */
    IF_CAN_EMPTY?: boolean;
}
export interface IEditType {
    value?: string;
    operator?: string;
    id?: string;
    field?: IFieldType;
    path?: any;
}
export interface IResutType {
    key: string;
    name: string;
    /**回溯天数 */
    reviewDay?: number;
    /**是否特殊项 */
    ifSpecial?: boolean;
    /**时间间隔 */
    dateRange?: number;
    /**结果类型 */
    resultType?: 'none' | 'both';
}
export type TINPUT_TYPE = 'SELECT' | 'MULTIPLE_SELECT' | 'NUMBER' | 'DATE' | 'DATE_TIME' | 'NUMBER_RANGE' | 'DATE_RANGE' | 'DATETIME_RANGE' | 'TEXT' | 'TEXT+MULTIPLE_SELECT' | 'AUTOCOMPLETE';
export interface IBuildItem {
    fieldDef?: IFieldType;
    value?: any;
    operation?: any;
    /**回溯天数 */
    reviewDay?: string | number;
    /**结果类型 */
    resultType?: string;
    resultType_type?: string;
    resultTypeLabel?: string;
    /**判断结果选择数据 */
    judgeResult?: any;
    /**时间间隔 */
    dateRange?: string | number;
}
export interface IPredicateItemDef {
    colDef: AgGridColDef[];
    data?: any[];
    filterCode?: string[];
    tableHeight?: string;
    /**所有数据(供检索用) */
    allDatas?: any[];
    tableTitle?: any;
    gridOptions?: GridOptions;
    gridConfigJson?: XDataGridProps;
}
export interface IValueItemDef {
    colDef: AgGridColDef[];
    data?: any[];
    rules?: any[];
    filterCode?: string[];
    tableHeight?: string;
    dropSelectWidth?: number;
    INPUT_TYPE?: string;
    /**所有数据(供检索用) */
    allDatas?: any[];
    tableTitle?: any;
    gridOptions?: GridOptions;
    gridConfigJson?: XDataGridProps;
}
export declare const getMatchOperatorList: (inputType: TINPUT_TYPE) => {
    name: string;
    label: string;
}[];
